==> wafwebaclcloudfront-2.21.0-sources.jar: software/amazon/awsconstructs/services/wafwebaclcloudfront/WafwebaclToCloudFront.java <==
package software.amazon.awsconstructs.services.wafwebaclcloudfront;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.65.0 (build 7a02b7f)", date = "2022-08-26T21:12:57.463Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.wafwebaclcloudfront.$Module.class, fqn = "@aws-solutions-constructs/aws-wafwebacl-cloudfront.WafwebaclToCloudFront")
public class WafwebaclToCloudFront extends software.constructs.Construct {

    protected WafwebaclToCloudFront(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected WafwebaclToCloudFront(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public WafwebaclToCloudFront(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFrontProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.Distribution getCloudFrontWebDistribution() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontWebDistribution", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.Distribution.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.wafv2.CfnWebACL getWebacl() {
        return software.amazon.jsii.Kernel.get(this, "webacl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.wafv2.CfnWebACL.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFrontProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFrontProps.Builder();
        }

        /**
         * The existing CloudFront instance that will be protected with the WAF web ACL.
         * <p>
         * This construct changes the CloudFront distribution by directly manipulating
         * the CloudFormation output, so this must be the Construct and cannot be
         * changed to the Interface (IDistribution)
         * <p>
         * @return {@code this}
         * @param existingCloudFrontWebDistribution The existing CloudFront instance that will be protected with the WAF web ACL. This parameter is required.
         */
        public Builder existingCloudFrontWebDistribution(final software.amazon.awscdk.services.cloudfront.Distribution existingCloudFrontWebDistribution) {
            this.props.existingCloudFrontWebDistribution(existingCloudFrontWebDistribution);
            return this;
        }

        /**
         * Existing instance of a WAF web ACL, an error will occur if this and props is set.
         * <p>
         * @return {@code this}
         * @param existingWebaclObj Existing instance of a WAF web ACL, an error will occur if this and props is set. This parameter is required.
         */
        public Builder existingWebaclObj(final software.amazon.awscdk.services.wafv2.CfnWebACL existingWebaclObj) {
            this.props.existingWebaclObj(existingWebaclObj);
            return this;
        }

        /**
         * Optional user-provided props to override the default props for the AWS WAF web ACL.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param webaclProps Optional user-provided props to override the default props for the AWS WAF web ACL. This parameter is required.
         */
        public Builder webaclProps(final software.amazon.awscdk.services.wafv2.CfnWebACLProps webaclProps) {
            this.props.webaclProps(webaclProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront}.
         */
        @Override
        public software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront build() {
            return new software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> wafwebaclcloudfront-2.71.0-sources.jar: software/amazon/awsconstructs/services/wafwebaclcloudfront/WafwebaclToCloudFront.java <==
package software.amazon.awsconstructs.services.wafwebaclcloudfront;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.103.1 (build bef2dea)", date = "2024-09-27T01:37:06.055Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.wafwebaclcloudfront.$Module.class, fqn = "@aws-solutions-constructs/aws-wafwebacl-cloudfront.WafwebaclToCloudFront")
public class WafwebaclToCloudFront extends software.constructs.Construct {

    protected WafwebaclToCloudFront(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected WafwebaclToCloudFront(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
     * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
     * @param props <ul><li>user provided props for the construct.</li></ul> This parameter is required.
     */
    public WafwebaclToCloudFront(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFrontProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cloudfront.Distribution getCloudFrontWebDistribution() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontWebDistribution", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.Distribution.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.wafv2.CfnWebACL getWebacl() {
        return software.amazon.jsii.Kernel.get(this, "webacl", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.wafv2.CfnWebACL.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope <ul><li>represents the scope for all the resources.</li></ul> This parameter is required.
         * @param id <ul><li>this is a a scope-unique id.</li></ul> This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFrontProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFrontProps.Builder();
        }

        /**
         * The existing CloudFront instance that will be protected with the WAF web ACL.
         * <p>
         * This construct changes the CloudFront distribution by directly manipulating
         * the CloudFormation output, so this must be the Construct and cannot be
         * changed to the Interface (IDistribution)
         * <p>
         * @return {@code this}
         * @param existingCloudFrontWebDistribution The existing CloudFront instance that will be protected with the WAF web ACL. This parameter is required.
         */
        public Builder existingCloudFrontWebDistribution(final software.amazon.awscdk.services.cloudfront.Distribution existingCloudFrontWebDistribution) {
            this.props.existingCloudFrontWebDistribution(existingCloudFrontWebDistribution);
            return this;
        }

        /**
         * Existing instance of a WAF web ACL, an error will occur if this and props is set.
         * <p>
         * @return {@code this}
         * @param existingWebaclObj Existing instance of a WAF web ACL, an error will occur if this and props is set. This parameter is required.
         */
        public Builder existingWebaclObj(final software.amazon.awscdk.services.wafv2.CfnWebACL existingWebaclObj) {
            this.props.existingWebaclObj(existingWebaclObj);
            return this;
        }

        /**
         * Optional user-provided props to override the default props for the AWS WAF web ACL.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param webaclProps Optional user-provided props to override the default props for the AWS WAF web ACL. This parameter is required.
         */
        public Builder webaclProps(final java.lang.Object webaclProps) {
            this.props.webaclProps(webaclProps);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront}.
         */
        @Override
        public software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront build() {
            return new software.amazon.awsconstructs.services.wafwebaclcloudfront.WafwebaclToCloudFront(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
